@@ -1,6 +1,5 @@
 mod ntp_source;
 mod server;
-pub mod subnet;
 
 use clock_steering::unix::UnixClock;
 use ntp_proto::{
@@ -83,13 +82,13 @@ impl CliArg {
 
                     if let Some((key, value)) = long_arg.split_once('=') {
                         if takes_argument.contains(&key) {
-                            processed.push(CliArg::Argument(key.to_string(), value.to_string()))
+                            processed.push(CliArg::Argument(key.to_string(), value.to_string()));
                         } else {
-                            invalid?
+                            invalid?;
                         }
                     } else if takes_argument.contains(&long_arg) {
                         if let Some(next) = arg_iter.next() {
-                            processed.push(CliArg::Argument(long_arg.to_string(), next))
+                            processed.push(CliArg::Argument(long_arg.to_string(), next));
                         } else {
                             Err(format!("'{}' expects an argument", &long_arg))?;
                         }
@@ -119,9 +118,8 @@ impl CliArg {
                                 Err(format!("'-{char}' expects an argument"))?;
                             }
                             break;
-                        } else {
-                            processed.push(CliArg::Flag(flag));
                         }
+                        processed.push(CliArg::Flag(flag));
                     }
                 }
                 _argument => rest.push(arg),
@@ -218,13 +216,14 @@ where
 
     if let Some(path) = data {
         tracing::info!("using custom clock {path:?}");
-        #[cfg(target_os = "linux")]
-        return Ok(NtpClockWrapper::new(
-            UnixClock::open(path).map_err(|e| serde::de::Error::custom(e.to_string()))?,
-        ));
 
         #[cfg(not(target_os = "linux"))]
         panic!("Custom clock paths not supported on this platform");
+
+        #[cfg(target_os = "linux")]
+        Ok(NtpClockWrapper::new(
+            UnixClock::open(path).map_err(|e| serde::de::Error::custom(e.to_string()))?,
+        ))
     } else {
         tracing::debug!("using REALTIME clock");
         Ok(NtpClockWrapper::new(UnixClock::CLOCK_REALTIME))
@@ -319,9 +318,9 @@ pub struct ObservabilityConfig {
 impl Default for ObservabilityConfig {
     fn default() -> Self {
         Self {
-            log_level: Default::default(),
+            log_level: None,
             ansi_colors: default_ansi_colors(),
-            observation_path: Default::default(),
+            observation_path: None,
             observation_permissions: default_observation_permissions(),
             metrics_exporter_listen: default_metrics_exporter_listen(),
         }
@@ -442,7 +441,6 @@ impl Config {
                 NtpSourceConfig::Standard(_) => count += 1,
                 NtpSourceConfig::Nts(_) => count += 1,
                 NtpSourceConfig::Pool(config) => count += config.first.count,
-                #[cfg(feature = "unstable_nts-pool")]
                 NtpSourceConfig::NtsPool(config) => count += config.first.count,
                 NtpSourceConfig::Sock(_) => count += 1,
                 #[cfg(feature = "pps")]
@@ -472,12 +470,15 @@ impl Config {
                     .synchronization_base
                     .minimum_agreeing_sources
         {
-            warn!("Fewer sources configured than are required to agree on the current time. Daemon will not change system time.");
+            warn!(
+                "Fewer sources configured than are required to agree on the current time. Daemon will not change system time."
+            );
             ok = false;
         }
 
         if self.sources.iter().any(|config| match config {
             NtpSourceConfig::Sock(_) => false,
+            #[cfg(feature = "pps")]
             NtpSourceConfig::Pps(_) => false,
             NtpSourceConfig::Standard(config) => {
                 matches!(config.first.ntp_version, ProtocolVersion::V5)
@@ -488,12 +489,13 @@ impl Config {
             NtpSourceConfig::Pool(config) => {
                 matches!(config.first.ntp_version, ProtocolVersion::V5)
             }
-            #[cfg(feature = "unstable_nts-pool")]
             NtpSourceConfig::NtsPool(config) => {
                 matches!(config.first.ntp_version, ProtocolVersion::V5)
             }
         }) {
-            warn!("Forcing a source into NTPv5, which is still a draft. There is no guarantee that the server will remain compatible with this or future versions of ntpd-rs.");
+            warn!(
+                "Forcing a source into NTPv5, which is still a draft. There is no guarantee that the server will remain compatible with this or future versions of ntpd-rs."
+            );
             ok = false;
         }
 
@@ -509,7 +511,10 @@ impl Config {
                         && server.accept_ntp_versions.contains(&NtpVersion::V4)
                 })
             {
-                warn!("Configured NTS for NTPv4 on port {}, but have no server listening on that port for NTPv4 traffic. If this is for an external ntp server, consider configuring a value for `ntp-server`.", ke_server.ntp_port.unwrap_or(123));
+                warn!(
+                    "Configured NTS for NTPv4 on port {}, but have no server listening on that port for NTPv4 traffic. If this is for an external ntp server, consider configuring a value for `ntp-server`.",
+                    ke_server.ntp_port.unwrap_or(123)
+                );
                 ok = false;
             }
 
@@ -519,7 +524,10 @@ impl Config {
                         && server.accept_ntp_versions.contains(&NtpVersion::V5)
                 })
             {
-                warn!("Configured NTS for NTPv5 on port {}, but have no server listening on that port for NTPv5 traffic. If this is for an external ntp server, consider configuring a value for `ntp-server`.", ke_server.ntp_port.unwrap_or(123));
+                warn!(
+                    "Configured NTS for NTPv5 on port {}, but have no server listening on that port for NTPv5 traffic. If this is for an external ntp server, consider configuring a value for `ntp-server`.",
+                    ke_server.ntp_port.unwrap_or(123)
+                );
                 ok = false;
             }
         }
@@ -558,6 +566,10 @@ impl From<toml::de::Error> for ConfigError {
 }
 
 #[cfg(test)]
+#[expect(
+    clippy::too_many_lines,
+    reason = "Long tests are not really a big problem"
+)]
 mod tests {
     use ntp_proto::{NtpDuration, ProtocolVersion, StepThreshold};
 
@@ -574,7 +586,7 @@ mod tests {
                     address: NormalizedAddress::new_unchecked("example.com", 123).into(),
                     ntp_version: ProtocolVersion::V4,
                 },
-                second: Default::default()
+                second: PartialSourceConfig::default()
             })]
         );
         assert!(config.observability.log_level.is_none());
@@ -591,7 +603,7 @@ mod tests {
                     address: NormalizedAddress::new_unchecked("example.com", 123).into(),
                     ntp_version: ProtocolVersion::V4,
                 },
-                second: Default::default()
+                second: PartialSourceConfig::default()
             })]
         );
 
@@ -606,7 +618,7 @@ mod tests {
                     address: NormalizedAddress::new_unchecked("example.com", 123).into(),
                     ntp_version: ProtocolVersion::V4,
                 },
-                second: Default::default()
+                second: PartialSourceConfig::default()
             })]
         );
         assert_eq!(
@@ -637,21 +649,25 @@ mod tests {
                     address: NormalizedAddress::new_unchecked("example.com", 123).into(),
                     ntp_version: ProtocolVersion::V4,
                 },
-                second: Default::default()
+                second: PartialSourceConfig::default()
             })]
         );
-        assert!(config
-            .synchronization
-            .synchronization_base
-            .single_step_panic_threshold
-            .forward
-            .is_none());
-        assert!(config
-            .synchronization
-            .synchronization_base
-            .single_step_panic_threshold
-            .backward
-            .is_none());
+        assert!(
+            config
+                .synchronization
+                .synchronization_base
+                .single_step_panic_threshold
+                .forward
+                .is_none()
+        );
+        assert!(
+            config
+                .synchronization
+                .synchronization_base
+                .single_step_panic_threshold
+                .backward
+                .is_none()
+        );
 
         let config: Config = toml::from_str(
             r#"
@@ -683,7 +699,7 @@ mod tests {
                     address: NormalizedAddress::new_unchecked("example.com", 123).into(),
                     ntp_version: ProtocolVersion::V4,
                 },
-                second: Default::default()
+                second: PartialSourceConfig::default()
             })]
         );
 
@@ -704,7 +720,7 @@ mod tests {
                     address: NormalizedAddress::new_unchecked("example.com", 123).into(),
                     ntp_version: ProtocolVersion::v4_upgrading_to_v5_with_default_tries(),
                 },
-                second: Default::default()
+                second: PartialSourceConfig::default()
             })]
         );
         assert!(config.observability.log_level.is_none());
@@ -825,7 +841,7 @@ mod tests {
     fn duration_not_nan() {
         #[derive(Debug, Deserialize)]
         struct Helper {
-            #[allow(unused)]
+            #[expect(unused)]
             duration: NtpDuration,
         }
 
@@ -843,7 +859,7 @@ mod tests {
     fn step_threshold_not_nan() {
         #[derive(Debug, Deserialize)]
         struct Helper {
-            #[allow(unused)]
+            #[expect(unused)]
             threshold: StepThreshold,
         }
 
