@@ -1,16 +1,18 @@
+#[cfg(test)]
+use std::sync::Mutex;
 use std::{
     fmt,
     net::{IpAddr, SocketAddr},
     ops::Deref,
     path::PathBuf,
-    sync::{Arc, Mutex},
+    sync::Arc,
 };
 
-use ntp_proto::{tls_utils::Certificate, ProtocolVersion};
 use ntp_proto::{PollInterval, PollIntervalLimits, SourceConfig};
+use ntp_proto::{ProtocolVersion, tls_utils::Certificate};
 use serde::{
-    de::{self, Visitor},
     Deserialize, Deserializer,
+    de::{self, Visitor},
 };
 
 use super::super::keyexchange::certificates_from_file;
@@ -133,7 +135,6 @@ fn max_sources_default() -> usize {
     4
 }
 
-#[cfg(feature = "unstable_nts-pool")]
 #[derive(Deserialize, Debug, PartialEq, Clone)]
 #[serde(rename_all = "kebab-case", deny_unknown_fields)]
 pub struct NtsPoolSourceConfig {
@@ -197,7 +198,9 @@ impl<'de> Deserialize<'de> for SockSourceConfig {
                             path = Some(map.next_value()?);
                         }
                         Field::MeasurementNoiseEstimate => {
-                            tracing::warn!("The measurement_noise_estimate field is deprecated. Please switch to using the precision field");
+                            tracing::warn!(
+                                "The measurement_noise_estimate field is deprecated. Please switch to using the precision field"
+                            );
                             if precision.is_some() {
                                 return Err(de::Error::duplicate_field(
                                     "measurement_noise_estimate",
@@ -333,7 +336,9 @@ impl<'de> Deserialize<'de> for PpsSourceConfig {
                             path = Some(map.next_value()?);
                         }
                         Field::MeasurementNoiseEstimate => {
-                            tracing::warn!("The measurement_noise_estimate field is deprecated. Please switch to using the precision field");
+                            tracing::warn!(
+                                "The measurement_noise_estimate field is deprecated. Please switch to using the precision field"
+                            );
                             if precision.is_some() {
                                 return Err(de::Error::duplicate_field(
                                     "measurement_noise_estimate",
@@ -403,7 +408,6 @@ pub enum NtpSourceConfig {
     Nts(FlattenedPair<NtsSourceConfig, PartialSourceConfig>),
     #[serde(rename = "pool")]
     Pool(FlattenedPair<PoolSourceConfig, PartialSourceConfig>),
-    #[cfg(feature = "unstable_nts-pool")]
     #[serde(rename = "nts-pool")]
     NtsPool(FlattenedPair<NtsPoolSourceConfig, PartialSourceConfig>),
     #[serde(rename = "sock")]
@@ -434,6 +438,7 @@ impl PartialEq for NormalizedAddress {
     }
 }
 
+#[cfg(test)]
 #[derive(Deserialize, Debug, Clone, Default)]
 struct HardcodedDnsResolve {
     #[cfg_attr(not(test), allow(unused))]
@@ -441,6 +446,7 @@ struct HardcodedDnsResolve {
     addresses: Arc<Mutex<Vec<SocketAddr>>>,
 }
 
+#[cfg(test)]
 impl From<Vec<SocketAddr>> for HardcodedDnsResolve {
     fn from(value: Vec<SocketAddr>) -> Self {
         Self {
@@ -548,7 +554,7 @@ impl NormalizedAddress {
                     if let Ok(socket_addr) = address_with_port.parse::<SocketAddr>() {
                         Ok((socket_addr.ip().to_string(), socket_addr.port()))
                     } else {
-                        Err(std::io::Error::new(std::io::ErrorKind::Other, e))
+                        Err(std::io::Error::other(e))
                     }
                 }
             }
@@ -558,7 +564,7 @@ impl NormalizedAddress {
             // the port is.
             match port.parse::<u16>() {
                 Ok(port) => Ok((server_name.to_string(), port)),
-                Err(e) => Err(std::io::Error::new(std::io::ErrorKind::Other, e)),
+                Err(e) => Err(std::io::Error::other(e)),
             }
         } else {
             // Not ipv6 and no port. As we cant reasonably check host
@@ -640,13 +646,17 @@ impl<'a> TryFrom<&'a str> for NtpSourceConfig {
         StandardSource::try_from(value).map(|first| {
             Self::Standard(FlattenedPair {
                 first,
-                second: Default::default(),
+                second: PartialSourceConfig::default(),
             })
         })
     }
 }
 
 #[cfg(test)]
+#[expect(
+    clippy::too_many_lines,
+    reason = "Long tests are not really a big problem"
+)]
 mod tests {
     use super::*;
 
@@ -660,7 +670,6 @@ mod tests {
             NtpSourceConfig::Standard(c) => c.first.address.to_string(),
             NtpSourceConfig::Nts(c) => c.first.address.to_string(),
             NtpSourceConfig::Pool(c) => c.first.addr.to_string(),
-            #[cfg(feature = "unstable_nts-pool")]
             NtpSourceConfig::NtsPool(c) => c.first.addr.to_string(),
             NtpSourceConfig::Sock(_c) => "".to_string(),
             #[cfg(feature = "pps")]
@@ -743,7 +752,6 @@ mod tests {
         assert!(matches!(test.source, NtpSourceConfig::Nts(_)));
         assert_eq!(source_addr(&test.source), "example.com:4460");
 
-        #[cfg(feature = "unstable_nts-pool")]
         {
             let test: TestConfig = toml::from_str(
                 r#"
