@@ -6,7 +6,7 @@ use std::{
 
 use ntp_proto::{KeySet, KeySetProvider};
 use tokio::sync::watch;
-use tracing::{instrument, warn, Span};
+use tracing::{Span, instrument, warn};
 
 use super::config::KeysetConfig;
 
@@ -22,7 +22,9 @@ pub async fn spawn(config: KeysetConfig) -> watch::Receiver<Arc<KeySet>> {
                 if perm.mode() as libc::mode_t & (libc::S_IWOTH | libc::S_IROTH | libc::S_IXOTH)
                     != 0
                 {
-                    warn!("Keyset file permissions: Others can interact with it. This is a potential security issue.");
+                    warn!(
+                        "Keyset file permissions: Others can interact with it. This is a potential security issue."
+                    );
                 }
             }
 
@@ -33,7 +35,7 @@ pub async fn spawn(config: KeysetConfig) -> watch::Receiver<Arc<KeySet>> {
                 },
             )
             .await
-            .unwrap_or_else(|e| Err(std::io::Error::new(std::io::ErrorKind::Other, e)))
+            .unwrap_or_else(|e| Err(std::io::Error::other(e)))
             .unwrap_or_else(|e| {
                 warn!(error = ?e, "Could not load nts server keys, starting with new set");
                 (
@@ -61,8 +63,8 @@ pub async fn spawn(config: KeysetConfig) -> watch::Receiver<Arc<KeySet>> {
         let _enter = span.enter();
         loop {
             // First save, then sleep. Ensures new sets created at boot are also saved.
-            if let Some(path) = &config.key_storage_path {
-                if let Err(e) = (|| -> std::io::Result<()> {
+            if let Some(path) = &config.key_storage_path
+                && let Err(e) = (|| -> std::io::Result<()> {
                     let mut output = OpenOptions::new()
                         .create(true)
                         .truncate(true)
@@ -70,14 +72,14 @@ pub async fn spawn(config: KeysetConfig) -> watch::Receiver<Arc<KeySet>> {
                         .mode(0o600)
                         .open(path)?;
                     provider.store(&mut output)
-                })() {
-                    if e.kind() == std::io::ErrorKind::NotFound
-                        || e.kind() == std::io::ErrorKind::PermissionDenied
-                    {
-                        warn!(error = ?e, "Could not store nts server keys, parent directory does not exist or has insufficient permissions");
-                    } else {
-                        warn!(error = ?e, "Could not store nts server keys");
-                    }
+                })()
+            {
+                if e.kind() == std::io::ErrorKind::NotFound
+                    || e.kind() == std::io::ErrorKind::PermissionDenied
+                {
+                    warn!(error = ?e, "Could not store nts server keys, parent directory does not exist or has insufficient permissions");
+                } else {
+                    warn!(error = ?e, "Could not store nts server keys");
                 }
             }
             if tx.send(provider.get()).is_err() {
