@@ -6,7 +6,7 @@ use ntp_proto::{
     OneWaySourceSnapshot, OneWaySourceUpdate, ReferenceId, SourceController, SystemSourceUpdate,
 };
 use tracing::debug;
-use tracing::{error, instrument, Instrument, Span};
+use tracing::{Instrument, Span, error, instrument};
 
 use tokio::net::UnixDatagram;
 
@@ -199,14 +199,13 @@ where
                         self.source.handle_message(update.message);
                     }
                     Err(e) => {
-                        error!("Error receiving system update: {:?}", e)
+                        error!("Error receiving system update: {:?}", e);
                     }
                 },
-            };
+            }
         }
     }
 
-    #[allow(clippy::too_many_arguments)]
     #[instrument(level = tracing::Level::ERROR, name = "Sock Source", skip(clock, channels, source))]
     pub fn spawn(
         index: SourceId,
@@ -251,7 +250,7 @@ mod tests {
     use crate::{
         daemon::{
             ntp_source::{MsgForSystem, SourceChannels},
-            sock_source::{create_socket, SampleError, SockSourceTask, SOCK_MAGIC},
+            sock_source::{SOCK_MAGIC, SampleError, SockSourceTask, create_socket},
             spawn::SourceId,
             util::EPOCH_OFFSET,
         },
